# Librarios

# Introduction

This is a Library Management Program built on python and MySql, which can be quite helpful in managing records of any ordinary library in world. It keeps your data safe and sound in MySql database which can be viewed at any instant, and thats definitely gonna save you a few pages by making all the manual work virtual and easy from its user-friendly interface.

<br/>

![alt text](https://media.discordapp.net/attachments/876404314782973984/938848283135213649/py-sql-menu.png?width=566&height=453)

<br/>

# It can do

- Add as many records
- Edit any record like phone number or book issued
- View a person's record
- Remove any person's record

With its user-friendly interface you can manage your whole library's record from a screen with ease.
<br/>

# Installation

You can simply clone my repository to get this project running on your device just by a single command

<br/>

``` 
git clone https://github.com/AnshumanKhatri14/Librarios.git
```
<br/>

Just copy out this in your terminal and use it to its fullest!








